==> silk-1.1.0.tar.gz: silk-1.1.0/autoconf/silk-python-info.py <==
#######################################################################
# Copyright (C) 2008 by Carnegie Mellon University.
#
# @OPENSOURCE_HEADER_START@
#
# Use of the SILK system and related source code is subject to the terms
# of the following licenses:
#
# GNU Public License (GPL) Rights pursuant to Version 2, June 1991
# Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
#
# NO WARRANTY
#
# ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
# PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
# PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
# "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
# KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
# LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
# MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
# OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
# SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
# TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
# WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
# LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
# CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
# CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
# DELIVERABLES UNDER THIS LICENSE.
#
# Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
# Mellon University, its trustees, officers, employees, and agents from
# all claims or demands made against them (and any related losses,
# expenses, or attorney's fees) arising out of, or relating to Licensee's
# and/or its sub licensees' negligent use or willful misuse of or
# negligent conduct or willful misconduct regarding the Software,
# facilities, or other rights or assistance granted by Carnegie Mellon
# University under this License, including, but not limited to, any
# claims of product liability, personal injury, death, damage to
# property, or violation of any laws or regulations.
#
# Carnegie Mellon University Software Engineering Institute authored
# documents are sponsored by the U.S. Department of Defense under
# Contract F19628-00-C-0003. Carnegie Mellon University retains
# copyrights in all material produced under this contract. The U.S.
# Government retains a non-exclusive, royalty-free license to publish or
# reproduce these documents, or allow others to do so, for U.S.
# Government purposes only pursuant to the copyright license under the
# contract clause at 252.227.7013.
#
# @OPENSOURCE_HEADER_END@
#
#######################################################################

#######################################################################
# $SiLK: silk-python-info.py 11953 2008-07-07 18:39:19Z mthomas $
#######################################################################

from distutils.sysconfig import *
import sys
import os
import re

if len(sys.argv) > 1 and sys.argv[1] == "--check-version":
    # See if we are python version >= 2.4 and < 3.0
    version_ok = (0x020400f0 <= sys.hexversion < 0x03000000)
    if version_ok:
        sys.exit(0)
    else:
        sys.exit(1)

if len(sys.argv) == 1 or sys.argv[1] != "--filename":
    sys.exit("Usage: %s {--check-version | --filename [filename]}" %
             sys.argv[0])

outfile = sys.argv[2]
python_prefix = os.getenv('PYTHONPREFIX')
python_site = os.getenv('PYTHONSITEDIR')
python_default_site = ""
version = ""
package_dest = ""
error_string = ""
include_dir = ""
ldflags = ""
cppflags = ""
libdir = ""
libname = ""
ldflags_embedded = ""

try:
    version = sys.version.split()[0]

    # Stash the config vars
    config_vars = get_config_vars()

    # Where should we install packages?
    python_default_site = get_python_lib(1,0)
    if python_site:
        package_dest = python_site
    else:
        if not python_prefix:
            package_dest = python_default_site
        elif python_default_site != get_python_lib(1,0,"BOGUS"):
            # prefix argument works
            package_dest = get_python_lib(1,0,python_prefix)
        else:
            # prefix argument does not work (Mac OS-X, some versions)
            error_string = "--with-python-prefix is broken on this version of Python.  Please use --with-python-site-dir instead."

    # Python include path
    include_dir = get_python_inc()

    # Python library location
    libdir = config_vars['LIBDIR']

    # Python library
    library = config_vars['LIBRARY']
    if not library:
        library = config_vars['LDLIBRARY']

    # Figure out the shortname of the library
    if library:
        libname = library[3:library.rfind('.')]

    # Needed for linking embedded python
    linkforshared = config_vars['LINKFORSHARED']
    localmodlibs = config_vars['LOCALMODLIBS']
    basemodlibs = config_vars['BASEMODLIBS']
    more_ldflags = config_vars['LDFLAGS']
    libs = config_vars['LIBS']
    ldflags_embedded = ' '.join([more_ldflags, linkforshared, 
                                 basemodlibs, localmodlibs, libs]).strip(' ')


    # Hack for the mac
    # Changes "-u _PyMac_Error Python.framework/Versions/2.4/Python" to
    # "-u _PyMac_Error -framework Python"
    ldflags_embedded = re.sub(r'(\A| )Python\.framework/[^ ]*',
                              ' -framework Python', ldflags_embedded)


    ### Build the output flags
    if include_dir:
        cppflags = "-I " + include_dir

    if libdir:
        ldflags = "-L" + libdir

    if libname:
        ldflags += " -l" + libname

    ldflags_embedded = ldflags_embedded + " " + ldflags

except:
    error_string = sys.exc_info()[1]
    pass

try:
    out = os.open(outfile, os.O_WRONLY | os.O_CREAT | os.O_EXCL)
except os.error, e:
    sys.exit("error: Cannot create %s: %s" % (outfile, e[1]))

os.write(out, 'PYTHON_VERSION="%s"\n' % version)
os.write(out, 'PYTHON_LIBDIR="%s"\n' % libdir)
os.write(out, 'PYTHON_LIBNAME="%s"\n' % libname)
os.write(out, 'PYTHON_SITE_PKG="%s"\n' % package_dest)
os.write(out, 'PYTHON_DEFAULT_SITE_PKG="%s"\n' % python_default_site)
os.write(out, 'PYTHON_CPPFLAGS="%s"\n' % cppflags)
os.write(out, 'PYTHON_LDFLAGS="%s"\n' % ldflags)
os.write(out, 'PYTHON_LDFLAGS_EMBEDDED="%s"\n' % ldflags_embedded)
os.write(out, 'PYTHON_ERROR="%s"\n' % error_string)
os.close(out)

==> silk-1.1.2.tar.gz: silk-1.1.2/autoconf/silk-python-info.py <==
#######################################################################
# Copyright (C) 2008 by Carnegie Mellon University.
#
# @OPENSOURCE_HEADER_START@
#
# Use of the SILK system and related source code is subject to the terms
# of the following licenses:
#
# GNU Public License (GPL) Rights pursuant to Version 2, June 1991
# Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
#
# NO WARRANTY
#
# ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
# PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
# PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
# "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
# KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
# LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
# MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
# OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
# SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
# TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
# WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
# LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
# CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
# CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
# DELIVERABLES UNDER THIS LICENSE.
#
# Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
# Mellon University, its trustees, officers, employees, and agents from
# all claims or demands made against them (and any related losses,
# expenses, or attorney's fees) arising out of, or relating to Licensee's
# and/or its sub licensees' negligent use or willful misuse of or
# negligent conduct or willful misconduct regarding the Software,
# facilities, or other rights or assistance granted by Carnegie Mellon
# University under this License, including, but not limited to, any
# claims of product liability, personal injury, death, damage to
# property, or violation of any laws or regulations.
#
# Carnegie Mellon University Software Engineering Institute authored
# documents are sponsored by the U.S. Department of Defense under
# Contract F19628-00-C-0003. Carnegie Mellon University retains
# copyrights in all material produced under this contract. The U.S.
# Government retains a non-exclusive, royalty-free license to publish or
# reproduce these documents, or allow others to do so, for U.S.
# Government purposes only pursuant to the copyright license under the
# contract clause at 252.227.7013.
#
# @OPENSOURCE_HEADER_END@
#
#######################################################################

#######################################################################
# $SiLK: silk-python-info.py 12171 2008-08-05 18:16:23Z mwd $
#######################################################################

from distutils.sysconfig import *
import sys
import os
import re

if len(sys.argv) > 1 and sys.argv[1] == "--check-version":
    # See if we are python version >= 2.4 and < 3.0
    version_ok = (0x020400f0 <= sys.hexversion < 0x03000000)
    if version_ok:
        sys.exit(0)
    else:
        sys.exit(1)

if len(sys.argv) == 1 or sys.argv[1] != "--filename":
    sys.exit("Usage: %s {--check-version | --filename [filename]}" %
             sys.argv[0])

outfile = sys.argv[2]
python_prefix = os.getenv('PYTHONPREFIX')
python_site = os.getenv('PYTHONSITEDIR')
python_default_site = ""
version = ""
package_dest = ""
error_string = ""
include_dir = ""
ldflags = ""
cppflags = ""
libdir = ""
libname = ""
ldflags_embedded = ""
pthread_option = ""
pthread_embedded_option = ""

try:
    version = sys.version.split()[0]

    # Stash the config vars
    config_vars = get_config_vars()

    # Where should we install packages?
    python_default_site = get_python_lib(1,0)
    if python_site:
        package_dest = python_site
    else:
        if not python_prefix:
            package_dest = python_default_site
        elif python_default_site != get_python_lib(1,0,"BOGUS"):
            # prefix argument works
            package_dest = get_python_lib(1,0,python_prefix)
        else:
            # prefix argument does not work (Mac OS-X, some versions)
            error_string = "--with-python-prefix is broken on this version of Python.  Please use --with-python-site-dir instead."

    # Python include path
    include_dir = get_python_inc()

    # Python library location
    libdir = config_vars['LIBDIR']

    # Python library
    library = config_vars['LIBRARY']
    if not library:
        library = config_vars['LDLIBRARY']

    # Figure out the shortname of the library
    if library:
        libname = library[3:library.rfind('.')]

    # Needed for linking embedded python
    linkforshared = config_vars['LINKFORSHARED']
    localmodlibs = config_vars['LOCALMODLIBS']
    basemodlibs = config_vars['BASEMODLIBS']
    more_ldflags = config_vars['LDFLAGS']
    libs = config_vars['LIBS']
    syslibs = config_vars['SYSLIBS']
    ldflags_embedded = ' '.join([more_ldflags, linkforshared,
                                 basemodlibs, localmodlibs, libs,
                                 syslibs]).strip(' ')


    # Hack for the mac
    # Changes "-u _PyMac_Error Python.framework/Versions/2.4/Python" to
    # "-u _PyMac_Error -framework Python"
    ldflags_embedded = re.sub(r'(\A| )Python\.framework/[^ ]*',
                              ' -framework Python', ldflags_embedded)


    ### Build the output flags
    if include_dir:
        cppflags = "-I " + include_dir

    if libdir:
        ldflags = "-L" + libdir

    if libname:
        ldflags += " -l" + libname

    ldflags_embedded = ldflags_embedded + " " + ldflags

    # Hack for pthread support
    split_ldflags = ldflags.split()
    split_ldflags_embedded = ldflags_embedded.split()
    thread_flags = ['-lpthread', '-pthread']

    in_ldflags = [x for x in (split_ldflags + config_vars['CC'].split())
                  if x in thread_flags]
    if in_ldflags:
        pthread_option = thread_flags['-lpthread' not in in_ldflags]

    in_ldflags_embedded = [x for x in 
                           (split_ldflags_embedded + config_vars['CC'].split())
                           if x in thread_flags]
    if in_ldflags_embedded:
        pthread_embedded_option = thread_flags['-lpthread' not in 
                                               in_ldflags_embedded]

    if pthread_option:
        split_ldflags = [x for x in split_ldflags 
                         if x not in thread_flags]
        ldflags = ' '.join(split_ldflags)


    if pthread_embedded_option:
        split_ldflags_embedded = [x for x in split_ldflags_embedded
                                  if x not in thread_flags]
        ldflags_embedded = ' '.join(split_ldflags_embedded)

    if (pthread_option and pthread_embedded_option and 
        (pthread_option == '-lpthread' or 
         pthread_embedded_option == '-lpthread')):
        pthread_option = '-lpthread'
        pthread_embedded_option = '-lpthread'

except:
    error_string = sys.exc_info()[1]
    pass

try:
    out = os.open(outfile, os.O_WRONLY | os.O_CREAT | os.O_EXCL)
except os.error, e:
    sys.exit("error: Cannot create %s: %s" % (outfile, e[1]))

os.write(out, "PYTHON_VERSION='%s'\n" % version)
os.write(out, "PYTHON_LIBDIR='%s'\n" % libdir)
os.write(out, "PYTHON_LIBNAME='%s'\n" % libname)
os.write(out, "PYTHON_SITE_PKG='%s'\n" % package_dest)
os.write(out, "PYTHON_DEFAULT_SITE_PKG='%s'\n" % python_default_site)
os.write(out, "PYTHON_CPPFLAGS='%s'\n" % cppflags)
os.write(out, "PYTHON_LDFLAGS='%s'\n" % ldflags)
os.write(out, "PYTHON_LDFLAGS_EMBEDDED='%s'\n" % ldflags_embedded)
os.write(out, "PYTHON_LDFLAGS_PTHREAD='%s'\n" % pthread_option)
os.write(out, "PYTHON_LDFLAGS_EMBEDDED_PTHREAD='%s'\n" % 
         pthread_embedded_option)
os.write(out, "PYTHON_ERROR='%s'\n" % error_string)
os.close(out)
